@@ -15,7 +15,7 @@ class FSMContextMixin:
     @property
     def fsm(cls) -> FSMContext:
         """Returns current fsm context."""
-        fsm = fsm_context.get(default=None)
+        fsm = fsm_context.get(None)
         if fsm is None:
             msg = "`FSMContext` is not set. Use `FSMContextMiddleware`"
             raise ValueError(msg)
